@@ -4,6 +4,13 @@
 def list2d(x, y, default=None):
     return [[default for xxx in range(x)] for xxx in range(y)]
 
+def reverse(data):
+    rev = list2d(len(data), len(data[0]))
+    for y in range(len(data)):
+        for x in range(len(data[0])):
+            rev[x][y] = data[y][x]
+    return rev
+
 class List2d:
     def __init__(self, *args):
         if len(args) == 1:
@@ -23,9 +30,15 @@ class List2d:
     def row(self, n):
         return self.data[n]
 
+    def rows(self):
+        return self.data
+
     def col(self, n):
         return [x[n] for x in self.data]
 
+    def cols(self):
+        return reverse(self.data)
+
     def get(self, x, y):
         return self.data[x][y]
 
@@ -33,11 +46,7 @@ class List2d:
         self.data[x][y] = val
 
     def reverse(self):
-        data = list2d(len(self.data[0]), len(self.data))
-        for y in range(len(self.data)):
-            for x in range(len(self.data[0])):
-                data[x][y] = self.data[y][x]
-        self.data = data
+        self.data = reverse(data)
 
     def duplicate(self):
         return List2d(self.data)
@@ -49,4 +58,4 @@ class List2d:
         return self.__unicode__()
 
     def __str__(self):
-        return self.__unicode__()
+        return self.__unicode__()
\ No newline at end of file
